==> vlc-1.2.0-pre1.tar.xz: vlc-1.2.0-pre1/modules/stream_filter/dash/mpd/BaseUrl.h <==
/*
 * BaseUrl.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef BASEURL_H_
#define BASEURL_H_

#include <string>

namespace dash
{
    namespace mpd
    {
        class BaseUrl
        {
            public:
                BaseUrl         (std::string url)   { this->url = url; }
                virtual ~BaseUrl()                  {}

                std::string getUrl() { return this->url; }

            private:
                std::string url;
        };
    }
}

#endif /* BASEURL_H_ */

==> vlc-2.0.9.tar.xz: vlc-2.0.9/modules/stream_filter/dash/mpd/BaseUrl.h <==
/*
 * BaseUrl.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef BASEURL_H_
#define BASEURL_H_

#include <string>

namespace dash
{
    namespace mpd
    {
        class BaseUrl
        {
            public:
            BaseUrl         (const std::string& url) : url(url) {}
                virtual ~BaseUrl()                  {}

                const std::string& getUrl() const { return this->url; }

            private:
                std::string url;
        };
    }
}

#endif /* BASEURL_H_ */
